/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.civicinfo.model;

import com.google.api.client.json.GenericJson;

/**
 * Information about an election administrative body (e.g. County Board of Elections).
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Civic Information API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class AdministrativeBody extends GenericJson {

  /**
   * A URL provided by this administrative body for information on absentee voting.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String absenteeVotingInfoUrl;

  /**
   * A URL provided by this administrative body to give contest information to the voter.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String ballotInfoUrl;

  /**
   * The mailing address of this administrative body.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private SimpleAddressType correspondenceAddress;

  /**
   * A URL provided by this administrative body for looking up general election information.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String electionInfoUrl;

  /**
   * The election officials for this election administrative body.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<ElectionOfficial> electionOfficials;

  static {
    // hack to force ProGuard to consider ElectionOfficial used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(ElectionOfficial.class);
  }

  /**
   * A URL provided by this administrative body for confirming that the voter is registered to vote.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String electionRegistrationConfirmationUrl;

  /**
   * A URL provided by this administrative body for looking up how to register to vote.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String electionRegistrationUrl;

  /**
   * A URL provided by this administrative body describing election rules to the voter.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String electionRulesUrl;

  /**
   * A description of the hours of operation for this administrative body.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String hoursOfOperation;

  /**
   * The name of this election administrative body.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * The physical address of this administrative body.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private SimpleAddressType physicalAddress;

  /**
   * A description of the services this administrative body may provide.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("voter_services")
  private java.util.List<String> voterServices;

  /**
   * A URL provided by this administrative body for looking up where to vote.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String votingLocationFinderUrl;

  /**
   * A URL provided by this administrative body for information on absentee voting.
   * The value returned may be {@code null}.
   */
  public String getAbsenteeVotingInfoUrl() {
    return absenteeVotingInfoUrl;
  }

  /**
   * A URL provided by this administrative body for information on absentee voting.
   * The value set may be {@code null}.
   */
  public AdministrativeBody setAbsenteeVotingInfoUrl(String absenteeVotingInfoUrl) {
    this.absenteeVotingInfoUrl = absenteeVotingInfoUrl;
    return this;
  }

  /**
   * A URL provided by this administrative body to give contest information to the voter.
   * The value returned may be {@code null}.
   */
  public String getBallotInfoUrl() {
    return ballotInfoUrl;
  }

  /**
   * A URL provided by this administrative body to give contest information to the voter.
   * The value set may be {@code null}.
   */
  public AdministrativeBody setBallotInfoUrl(String ballotInfoUrl) {
    this.ballotInfoUrl = ballotInfoUrl;
    return this;
  }

  /**
   * The mailing address of this administrative body.
   * The value returned may be {@code null}.
   */
  public SimpleAddressType getCorrespondenceAddress() {
    return correspondenceAddress;
  }

  /**
   * The mailing address of this administrative body.
   * The value set may be {@code null}.
   */
  public AdministrativeBody setCorrespondenceAddress(SimpleAddressType correspondenceAddress) {
    this.correspondenceAddress = correspondenceAddress;
    return this;
  }

  /**
   * A URL provided by this administrative body for looking up general election information.
   * The value returned may be {@code null}.
   */
  public String getElectionInfoUrl() {
    return electionInfoUrl;
  }

  /**
   * A URL provided by this administrative body for looking up general election information.
   * The value set may be {@code null}.
   */
  public AdministrativeBody setElectionInfoUrl(String electionInfoUrl) {
    this.electionInfoUrl = electionInfoUrl;
    return this;
  }

  /**
   * The election officials for this election administrative body.
   * The value returned may be {@code null}.
   */
  public java.util.List<ElectionOfficial> getElectionOfficials() {
    return electionOfficials;
  }

  /**
   * The election officials for this election administrative body.
   * The value set may be {@code null}.
   */
  public AdministrativeBody setElectionOfficials(java.util.List<ElectionOfficial> electionOfficials) {
    this.electionOfficials = electionOfficials;
    return this;
  }

  /**
   * A URL provided by this administrative body for confirming that the voter is registered to vote.
   * The value returned may be {@code null}.
   */
  public String getElectionRegistrationConfirmationUrl() {
    return electionRegistrationConfirmationUrl;
  }

  /**
   * A URL provided by this administrative body for confirming that the voter is registered to vote.
   * The value set may be {@code null}.
   */
  public AdministrativeBody setElectionRegistrationConfirmationUrl(String electionRegistrationConfirmationUrl) {
    this.electionRegistrationConfirmationUrl = electionRegistrationConfirmationUrl;
    return this;
  }

  /**
   * A URL provided by this administrative body for looking up how to register to vote.
   * The value returned may be {@code null}.
   */
  public String getElectionRegistrationUrl() {
    return electionRegistrationUrl;
  }

  /**
   * A URL provided by this administrative body for looking up how to register to vote.
   * The value set may be {@code null}.
   */
  public AdministrativeBody setElectionRegistrationUrl(String electionRegistrationUrl) {
    this.electionRegistrationUrl = electionRegistrationUrl;
    return this;
  }

  /**
   * A URL provided by this administrative body describing election rules to the voter.
   * The value returned may be {@code null}.
   */
  public String getElectionRulesUrl() {
    return electionRulesUrl;
  }

  /**
   * A URL provided by this administrative body describing election rules to the voter.
   * The value set may be {@code null}.
   */
  public AdministrativeBody setElectionRulesUrl(String electionRulesUrl) {
    this.electionRulesUrl = electionRulesUrl;
    return this;
  }

  /**
   * A description of the hours of operation for this administrative body.
   * The value returned may be {@code null}.
   */
  public String getHoursOfOperation() {
    return hoursOfOperation;
  }

  /**
   * A description of the hours of operation for this administrative body.
   * The value set may be {@code null}.
   */
  public AdministrativeBody setHoursOfOperation(String hoursOfOperation) {
    this.hoursOfOperation = hoursOfOperation;
    return this;
  }

  /**
   * The name of this election administrative body.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The name of this election administrative body.
   * The value set may be {@code null}.
   */
  public AdministrativeBody setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * The physical address of this administrative body.
   * The value returned may be {@code null}.
   */
  public SimpleAddressType getPhysicalAddress() {
    return physicalAddress;
  }

  /**
   * The physical address of this administrative body.
   * The value set may be {@code null}.
   */
  public AdministrativeBody setPhysicalAddress(SimpleAddressType physicalAddress) {
    this.physicalAddress = physicalAddress;
    return this;
  }

  /**
   * A description of the services this administrative body may provide.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getVoterServices() {
    return voterServices;
  }

  /**
   * A description of the services this administrative body may provide.
   * The value set may be {@code null}.
   */
  public AdministrativeBody setVoterServices(java.util.List<String> voterServices) {
    this.voterServices = voterServices;
    return this;
  }

  /**
   * A URL provided by this administrative body for looking up where to vote.
   * The value returned may be {@code null}.
   */
  public String getVotingLocationFinderUrl() {
    return votingLocationFinderUrl;
  }

  /**
   * A URL provided by this administrative body for looking up where to vote.
   * The value set may be {@code null}.
   */
  public AdministrativeBody setVotingLocationFinderUrl(String votingLocationFinderUrl) {
    this.votingLocationFinderUrl = votingLocationFinderUrl;
    return this;
  }

}
